@@ -29,6 +29,7 @@ impl std::fmt::Display for Relations {
     }
 }
 
+
 impl Relations {
     pub fn new() -> Self {
         Self {  
@@ -68,6 +69,16 @@ impl Relations {
         file_output
     }
 
+    /// Only display stale files
+    pub fn display_stale_files(&self, depth: usize) -> Result<(), RifError> {
+        for path in self.files.keys().sorted() {
+            if let FileStatus::Stale = self.files.get(path).unwrap().status {
+                self.display_file_depth(path, depth)?;
+            }
+        }
+        Ok(())
+    }
+
     /// Print a single file's relation 
     ///
     /// # Args
@@ -92,6 +103,10 @@ impl Relations {
     ///
     /// * `depth` - Desired depth value to display
     pub fn display_depth(&self, depth: usize) -> Result<(), RifError> {
+        if depth == 0 {
+            println!("{}", self);
+            return Ok(());
+        } 
         for path in self.files.keys().cloned().sorted() {
             // This should always work theoritically
             let single_file = self.files.get(&path).unwrap();
@@ -122,7 +137,7 @@ impl Relations {
             print!("- > {} {}", ref_item_key.display(), ref_item.status);
             if let FileStatus::Stale = parent_file.status {
                 if current_time < ref_item.timestamp {
-                    print!(" {}", utils::yellow("Updated"));
+                    print!("{}", utils::yellow("(u)"));
                 }
             }
             print!("\n");
@@ -594,18 +609,18 @@ impl Relations {
             println!("    All files are up to date.");
         } else {
             if deleted_log.len() != 0 {println!("{}", deleted_log);}
-            println!("{}", modified_log);
+            if modified_log.len() != 0 {println!("{}", modified_log);}
         }
 
         Ok(())
     }
 
-    pub fn get_deleted_files(&self) -> HashSet<&Path> {
+    pub fn get_deleted_files(&self) -> HashSet<PathBuf> {
         let mut set = HashSet::new();
         for path in self.files.keys() {
             // If file doesn't exist, print as delted
             if !path.exists() {
-                set.insert(path.as_path());
+                set.insert(path.to_owned());
             }
         }
 
@@ -619,6 +634,11 @@ impl Relations {
         let mut modified: Vec<PathBuf> = vec![];
 
         for (path, file) in self.files.iter() {
+            // File is deleted
+            if !path.exists() {
+                continue;
+            }
+
             let system_time = utils::get_file_unix_time(path)?;
             if file.last_modified < system_time {
                 modified.push(path.clone());
